@@ -27,7 +27,7 @@
 __all__ = ['object_store']
 
 import os
-import pickle as pkl
+import cPickle as pkl
 import shutil
 
 def object_store(path,obj):
