@@ -22,7 +22,7 @@
 # Author: Daniele Bigoni
 #
 
-__all__ = ['RunUnitTests','RunTestKL1D','RunTestKL2D','RunTestRandomSampling']
+__all__ = ['RunUnitTests','RunTestKL1D','RunTestKL2D','RunTestRandomSampling','RunTestTimingPreFit']
 
 def RunTestRandomSampling(maxprocs=None,PLOTTING=False):
     import TestRandomSampling
@@ -36,6 +36,10 @@ def RunTestKL2D(maxprocs=None,PLOTTING=False):
     import TestKL2D
     TestKL2D.run(maxprocs,PLOTTING)
 
+def RunTestTimingPreFit(maxprocs=None,PLOTTING=False):
+    import TestTimingPreFit
+    TestTimingPreFit.run(maxprocs,PLOTTING)
+
 def RunUnitTests(maxprocs=None,PLOTTING=False):
     """ Runs all the unit tests.
     
